window.BENCHMARK_DATA = {
  "lastUpdate": 1634328810850,
  "repoUrl": "https://github.com/Anexen/pyxirr",
  "entries": {
    "Rust Benchmark": [
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "41a41017414dbc90fb51be2f092ad8b591524fdd",
          "message": "use personal github token",
          "timestamp": "2021-05-20T19:05:30+03:00",
          "tree_id": "a57fee16619b8f4b19d1eea1b9efd26210f927a8",
          "url": "https://github.com/Anexen/pyxirr/commit/41a41017414dbc90fb51be2f092ad8b591524fdd"
        },
        "date": 1621536877683,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 17281278,
            "range": "± 935476",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 43999237,
            "range": "± 2267125",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 49174,
            "range": "± 4079",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 438682,
            "range": "± 26892",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_10000",
            "value": 3871309,
            "range": "± 239165",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 815819,
            "range": "± 49052",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4069659,
            "range": "± 205424",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_10000",
            "value": 34162292,
            "range": "± 1536264",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "41a41017414dbc90fb51be2f092ad8b591524fdd",
          "message": "use personal github token",
          "timestamp": "2021-05-20T19:05:30+03:00",
          "tree_id": "a57fee16619b8f4b19d1eea1b9efd26210f927a8",
          "url": "https://github.com/Anexen/pyxirr/commit/41a41017414dbc90fb51be2f092ad8b591524fdd"
        },
        "date": 1621544602900,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 17761540,
            "range": "± 2643822",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 46896990,
            "range": "± 5014131",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 54508,
            "range": "± 5129",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 473401,
            "range": "± 44226",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_10000",
            "value": 4284330,
            "range": "± 847080",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 1036608,
            "range": "± 385375",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 5348782,
            "range": "± 1438266",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_10000",
            "value": 40253945,
            "range": "± 8140047",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "64622498b4bfaf2775c7274d531c60d387baaa23",
          "message": "smaller benchmark",
          "timestamp": "2021-05-21T10:26:19+03:00",
          "tree_id": "70066e1f25fe1e83c0ba44b1bf3167eba7e60dd2",
          "url": "https://github.com/Anexen/pyxirr/commit/64622498b4bfaf2775c7274d531c60d387baaa23"
        },
        "date": 1621582172351,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 18868544,
            "range": "± 2644874",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 49860048,
            "range": "± 7258488",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 62259461,
            "range": "± 5258023",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 53360,
            "range": "± 4232",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 475464,
            "range": "± 52591",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 290030,
            "range": "± 30422",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 1009112,
            "range": "± 65022",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4584552,
            "range": "± 389809",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 3406925,
            "range": "± 369652",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "4e907a574707fc131a4fdd199c67b97c43bcf494",
          "message": "bench image",
          "timestamp": "2021-05-21T12:09:27+03:00",
          "tree_id": "0e299973042a90696e8b40be8afa2d423b7791c7",
          "url": "https://github.com/Anexen/pyxirr/commit/4e907a574707fc131a4fdd199c67b97c43bcf494"
        },
        "date": 1621588352087,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 17457855,
            "range": "± 2245319",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 45323584,
            "range": "± 5204640",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 57719141,
            "range": "± 5035734",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 49266,
            "range": "± 7319",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 437041,
            "range": "± 52170",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 266368,
            "range": "± 30532",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 906064,
            "range": "± 108891",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4122530,
            "range": "± 649319",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 3025689,
            "range": "± 429650",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Alexander Volkovsky",
            "username": "Anexen"
          },
          "committer": {
            "email": "noreply@github.com",
            "name": "GitHub",
            "username": "web-flow"
          },
          "distinct": true,
          "id": "1c69f2fe00fbd06d3a0a6010bcd3019f51aa4a23",
          "message": "Github Actions benchmark (#5)",
          "timestamp": "2021-05-21T12:22:34+03:00",
          "tree_id": "7ea1f92fcd8be4d1b77c7487074d84ead8e814da",
          "url": "https://github.com/Anexen/pyxirr/commit/1c69f2fe00fbd06d3a0a6010bcd3019f51aa4a23"
        },
        "date": 1621589125939,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 17831727,
            "range": "± 111957",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 45158174,
            "range": "± 605624",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 57810365,
            "range": "± 628856",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 51454,
            "range": "± 2468",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 449108,
            "range": "± 23287",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 279131,
            "range": "± 12805",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 841052,
            "range": "± 40155",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4171548,
            "range": "± 109366",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 2899356,
            "range": "± 107439",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Alexander Volkovsky",
            "username": "Anexen"
          },
          "committer": {
            "email": "noreply@github.com",
            "name": "GitHub",
            "username": "web-flow"
          },
          "distinct": true,
          "id": "c91f88143d5fbf0899e09bf3b8c9f07b1252b061",
          "message": "added mirr + fv + performance improvements (#6)",
          "timestamp": "2021-05-24T08:02:48+03:00",
          "tree_id": "5121e0cb891e89a11a9a16d48396b4b0784555d9",
          "url": "https://github.com/Anexen/pyxirr/commit/c91f88143d5fbf0899e09bf3b8c9f07b1252b061"
        },
        "date": 1621832746476,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 18958591,
            "range": "± 2285506",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 49955946,
            "range": "± 3444758",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 62264470,
            "range": "± 3999132",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 53609,
            "range": "± 8809",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 483211,
            "range": "± 69413",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 288936,
            "range": "± 34475",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 992727,
            "range": "± 144201",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4657267,
            "range": "± 597139",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 3384921,
            "range": "± 682012",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "c4091b8f35803411b20ed496d2b50378c0472b45",
          "message": "bump version to 0.5.0",
          "timestamp": "2021-05-24T08:24:54+03:00",
          "tree_id": "ef72927f8acc40b06b09d557ac29b144b5e2e9fa",
          "url": "https://github.com/Anexen/pyxirr/commit/c4091b8f35803411b20ed496d2b50378c0472b45"
        },
        "date": 1621834092992,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 17234882,
            "range": "± 2062641",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 48030975,
            "range": "± 8577639",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 56536806,
            "range": "± 6454213",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 48665,
            "range": "± 5464",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 435105,
            "range": "± 55663",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 265799,
            "range": "± 36164",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 947368,
            "range": "± 105458",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4353573,
            "range": "± 375069",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 3040760,
            "range": "± 299094",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "fcba0be0375cbf55a65124289bcaa13b3982c5ec",
          "message": "update readme; add npf bench; remove pyo3 wrappers from core",
          "timestamp": "2021-05-25T13:24:30+03:00",
          "tree_id": "73bf523efeaeeba2ff74e2274bccc0ede928fee6",
          "url": "https://github.com/Anexen/pyxirr/commit/fcba0be0375cbf55a65124289bcaa13b3982c5ec"
        },
        "date": 1621938544275,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 18934468,
            "range": "± 1790689",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 46986464,
            "range": "± 4493727",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 60136883,
            "range": "± 5855619",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 53507,
            "range": "± 10344",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 481555,
            "range": "± 65972",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 278238,
            "range": "± 33034",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 1016470,
            "range": "± 162915",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4674704,
            "range": "± 727339",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 3429940,
            "range": "± 482169",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "53946ba56ddc9cdf06feb7f8051b7144061e5038",
          "message": "fix readme content type",
          "timestamp": "2021-05-25T13:40:35+03:00",
          "tree_id": "462312e95fbf20d4610f9832a8f8a1eb215c3c39",
          "url": "https://github.com/Anexen/pyxirr/commit/53946ba56ddc9cdf06feb7f8051b7144061e5038"
        },
        "date": 1621939366420,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 17603319,
            "range": "± 293940",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 44949558,
            "range": "± 850718",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 58196273,
            "range": "± 815999",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 50301,
            "range": "± 2811",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 443169,
            "range": "± 26223",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 272969,
            "range": "± 7733",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 827868,
            "range": "± 31184",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4207565,
            "range": "± 153194",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 2972539,
            "range": "± 70402",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "ae5e170a688b1364f8f0c84498e5f210493c4bf3",
          "message": "Merge branch 'main' of github.com:Anexen/pyxirr",
          "timestamp": "2021-05-31T13:17:31+03:00",
          "tree_id": "f8fd9632989d2b1b20f664e98e449277a19adcd9",
          "url": "https://github.com/Anexen/pyxirr/commit/ae5e170a688b1364f8f0c84498e5f210493c4bf3"
        },
        "date": 1622456425530,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 16676809,
            "range": "± 2245672",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 42241296,
            "range": "± 2691423",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 55174188,
            "range": "± 4983320",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 47693,
            "range": "± 6649",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 431669,
            "range": "± 62444",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 256077,
            "range": "± 31005",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 948683,
            "range": "± 173440",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4254204,
            "range": "± 705819",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 3041868,
            "range": "± 285987",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "1fd1ae91449c0739dbfc63446a40b7caf03b4439",
          "message": "improve the docs; NPV compatibility mode with Excel",
          "timestamp": "2021-06-03T12:17:17+03:00",
          "tree_id": "fa3c34902ffeb67f5bb72fd9079bdc2d3b7acbce",
          "url": "https://github.com/Anexen/pyxirr/commit/1fd1ae91449c0739dbfc63446a40b7caf03b4439"
        },
        "date": 1622711995281,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 18153264,
            "range": "± 279555",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 46470293,
            "range": "± 333167",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 59340683,
            "range": "± 599865",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 52883,
            "range": "± 528",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 466542,
            "range": "± 6356",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 287486,
            "range": "± 5028",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 866690,
            "range": "± 8744",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4334597,
            "range": "± 7700",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 3040486,
            "range": "± 13325",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "ecf77009fed5e3e7bfa35886f4be5e9bd924f973",
          "message": "update npv docs",
          "timestamp": "2021-06-04T15:31:27+03:00",
          "tree_id": "cf34dd548d7e5a1da620c575d9a9e1fbe277a4bb",
          "url": "https://github.com/Anexen/pyxirr/commit/ecf77009fed5e3e7bfa35886f4be5e9bd924f973"
        },
        "date": 1622810050212,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 17450426,
            "range": "± 2024088",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 43073319,
            "range": "± 2054800",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 55589766,
            "range": "± 4753609",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 44940,
            "range": "± 9028",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 390047,
            "range": "± 52496",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 245390,
            "range": "± 33280",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 885473,
            "range": "± 76756",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4373725,
            "range": "± 462918",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 2892210,
            "range": "± 273369",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "9f552b67b888ce140b8361a3aa174f7c0c639563",
          "message": "Merge branch 'main' of github.com:Anexen/pyxirr",
          "timestamp": "2021-06-04T16:01:06+03:00",
          "tree_id": "e917bebb658405b1eb37474147936d60d24bef51",
          "url": "https://github.com/Anexen/pyxirr/commit/9f552b67b888ce140b8361a3aa174f7c0c639563"
        },
        "date": 1622811975971,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 16795943,
            "range": "± 2457993",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 44087203,
            "range": "± 7118686",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 53227021,
            "range": "± 5830917",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 44269,
            "range": "± 8520",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 395628,
            "range": "± 94376",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 234668,
            "range": "± 40833",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 898736,
            "range": "± 196182",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4203411,
            "range": "± 926132",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 2954668,
            "range": "± 510918",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Alexander Volkovsky",
            "username": "Anexen"
          },
          "committer": {
            "email": "noreply@github.com",
            "name": "GitHub",
            "username": "web-flow"
          },
          "distinct": true,
          "id": "b532fe45e93e6e77101cf7f5b3733367fbaeb5c0",
          "message": "PMT, NPER (#9)",
          "timestamp": "2021-07-25T01:17:42+03:00",
          "tree_id": "a3c9a3471df3987fcc6a865c07feb08dc050fbba",
          "url": "https://github.com/Anexen/pyxirr/commit/b532fe45e93e6e77101cf7f5b3733367fbaeb5c0"
        },
        "date": 1627165221573,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 17499162,
            "range": "± 714714",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 44209266,
            "range": "± 1018597",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 57451926,
            "range": "± 1145812",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 47790,
            "range": "± 1756",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 415953,
            "range": "± 21170",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 257388,
            "range": "± 10544",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 801751,
            "range": "± 6123",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4123371,
            "range": "± 63372",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 2857086,
            "range": "± 57387",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "f4cdfae2e47263e2875016381c8bb96bec0cd384",
          "message": "bump version to 0.6",
          "timestamp": "2021-07-25T01:23:57+03:00",
          "tree_id": "a6f5c0c4f61bce8b63d7a738666aef1734a07137",
          "url": "https://github.com/Anexen/pyxirr/commit/f4cdfae2e47263e2875016381c8bb96bec0cd384"
        },
        "date": 1627165714560,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 17846435,
            "range": "± 1333048",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 46647285,
            "range": "± 4381376",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 60309875,
            "range": "± 4543097",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 50865,
            "range": "± 11515",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 436169,
            "range": "± 51059",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 277282,
            "range": "± 42026",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 976861,
            "range": "± 206258",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4338594,
            "range": "± 623017",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 3203036,
            "range": "± 441827",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Alexander Volkovsky",
            "username": "Anexen"
          },
          "committer": {
            "email": "noreply@github.com",
            "name": "GitHub",
            "username": "web-flow"
          },
          "distinct": true,
          "id": "85218b882bf9411a927a6151f1672e8f030928ae",
          "message": "NFV, XNFV (#11)\n\nNFV, XFV, XNFV + refactor",
          "timestamp": "2021-07-28T09:07:41+03:00",
          "tree_id": "5a966cd29fbbf7e98b9e2c1cb5e89cbda47a0977",
          "url": "https://github.com/Anexen/pyxirr/commit/85218b882bf9411a927a6151f1672e8f030928ae"
        },
        "date": 1627452628135,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 16841916,
            "range": "± 1114217",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 44092324,
            "range": "± 3914190",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 57157809,
            "range": "± 5115328",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 45504,
            "range": "± 4888",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 397745,
            "range": "± 40774",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 253093,
            "range": "± 56766",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 900441,
            "range": "± 106691",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4243848,
            "range": "± 569151",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 2959699,
            "range": "± 328835",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "7301b86ee9b4670050ed8293f6fadcc458090460",
          "message": "bump version to 0.6.1",
          "timestamp": "2021-07-28T14:00:42+03:00",
          "tree_id": "9c5161a124cef58fa68a2f030c5aa928425a9d88",
          "url": "https://github.com/Anexen/pyxirr/commit/7301b86ee9b4670050ed8293f6fadcc458090460"
        },
        "date": 1627470314881,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 19419053,
            "range": "± 2733622",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 50381213,
            "range": "± 2356630",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 64255452,
            "range": "± 4228234",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 51475,
            "range": "± 4714",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 455647,
            "range": "± 36357",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 280217,
            "range": "± 23979",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 1017151,
            "range": "± 111913",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4626777,
            "range": "± 627886",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 3295630,
            "range": "± 365983",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "774b538543bd4a1b8425b3863f57e04daa3457f6",
          "message": "bump version to 0.6.2",
          "timestamp": "2021-08-06T08:34:20+03:00",
          "tree_id": "e83c9b9425dd57ad0b0a635d84e8324efdc4b525",
          "url": "https://github.com/Anexen/pyxirr/commit/774b538543bd4a1b8425b3863f57e04daa3457f6"
        },
        "date": 1628228275604,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 17517858,
            "range": "± 2334503",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 45649568,
            "range": "± 3747439",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 58891735,
            "range": "± 4718766",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 47932,
            "range": "± 7748",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 433790,
            "range": "± 71796",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 265429,
            "range": "± 45078",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 1000190,
            "range": "± 174505",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 4652384,
            "range": "± 1212004",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 3324031,
            "range": "± 438182",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Alexander Volkovsky",
            "username": "Anexen"
          },
          "committer": {
            "email": "noreply@github.com",
            "name": "GitHub",
            "username": "web-flow"
          },
          "distinct": true,
          "id": "4591e58dc44df4d9c28ec26bd0aa96d679eb129a",
          "message": "XIRR improvements (#15)\n\n* add more xirr tests\r\n\r\n* handle XIRR close to -1\r\n\r\n* fix nfv signature; always return None instead of nan",
          "timestamp": "2021-08-17T23:34:05+03:00",
          "tree_id": "6bf1563f0abe4b1a8b2ab68adac2f45bb135d027",
          "url": "https://github.com/Anexen/pyxirr/commit/4591e58dc44df4d9c28ec26bd0aa96d679eb129a"
        },
        "date": 1629232575173,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 15147450,
            "range": "± 42629",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 38173503,
            "range": "± 219022",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 49235102,
            "range": "± 193495",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 41880,
            "range": "± 555",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 366457,
            "range": "± 18005",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 225892,
            "range": "± 1816",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 709607,
            "range": "± 10262",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 3531798,
            "range": "± 14053",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 2430346,
            "range": "± 8465",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "2dc63451464dc5018909f6a44a1e86e6d014fac4",
          "message": "bump version to 0.6.3",
          "timestamp": "2021-08-17T23:42:23+03:00",
          "tree_id": "42c79e67cc7ec1b1d221a5a5390bc8870c63ec13",
          "url": "https://github.com/Anexen/pyxirr/commit/2dc63451464dc5018909f6a44a1e86e6d014fac4"
        },
        "date": 1629233110951,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 14442456,
            "range": "± 41623",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 36442674,
            "range": "± 278558",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 46985716,
            "range": "± 229327",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 41602,
            "range": "± 444",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 365089,
            "range": "± 16395",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 224746,
            "range": "± 657",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 705909,
            "range": "± 6649",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 3463710,
            "range": "± 12923",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 2439829,
            "range": "± 118097",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "dd232e633db3726217d969c1a5ca25c2b63a33a8",
          "message": "wheels for python 3.10",
          "timestamp": "2021-10-05T21:16:34+03:00",
          "tree_id": "d48ca856868b76ff56401259c7d71c3e5f33e53b",
          "url": "https://github.com/Anexen/pyxirr/commit/dd232e633db3726217d969c1a5ca25c2b63a33a8"
        },
        "date": 1633457937940,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 14698377,
            "range": "± 26294",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 36985943,
            "range": "± 180722",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 47843738,
            "range": "± 217804",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 41530,
            "range": "± 442",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 368686,
            "range": "± 7541",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 224797,
            "range": "± 11199",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 705477,
            "range": "± 4920",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 3483412,
            "range": "± 7999",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 2438863,
            "range": "± 9318",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "2ee135629129c94115b47503fa0bf55869ab7759",
          "message": "Merge branch 'main' of github.com:Anexen/pyxirr",
          "timestamp": "2021-10-05T21:20:43+03:00",
          "tree_id": "3fab163a6e5a51798dcb3aa7bee97090be65645b",
          "url": "https://github.com/Anexen/pyxirr/commit/2ee135629129c94115b47503fa0bf55869ab7759"
        },
        "date": 1633458135956,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 12969342,
            "range": "± 1957409",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 32659186,
            "range": "± 182814",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 42328093,
            "range": "± 151240",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 36695,
            "range": "± 484",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 324887,
            "range": "± 16877",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 198149,
            "range": "± 12989",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 698899,
            "range": "± 4528",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 3455859,
            "range": "± 11689",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 2412930,
            "range": "± 9990",
            "unit": "ns/iter"
          }
        ]
      },
      {
        "commit": {
          "author": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "committer": {
            "email": "avolk93@gmail.com",
            "name": "Anexen",
            "username": "Anexen"
          },
          "distinct": true,
          "id": "17434f8687b8eefeb412df0edf5e6df9a0d70c65",
          "message": "bump version to 0.6.4",
          "timestamp": "2021-10-15T23:11:09+03:00",
          "tree_id": "7803b390c122c1707dc401fa969c738978608cf1",
          "url": "https://github.com/Anexen/pyxirr/commit/17434f8687b8eefeb412df0edf5e6df9a0d70c65"
        },
        "date": 1634328810833,
        "tool": "cargo",
        "benches": [
          {
            "name": "bench_python_100",
            "value": 14878175,
            "range": "± 837130",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_1000",
            "value": 37913833,
            "range": "± 2681919",
            "unit": "ns/iter"
          },
          {
            "name": "bench_python_500",
            "value": 47918752,
            "range": "± 746711",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_100",
            "value": 41643,
            "range": "± 457",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_1000",
            "value": 362898,
            "range": "± 17787",
            "unit": "ns/iter"
          },
          {
            "name": "bench_rust_500",
            "value": 224098,
            "range": "± 9653",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_100",
            "value": 715927,
            "range": "± 6419",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_1000",
            "value": 3581566,
            "range": "± 13584",
            "unit": "ns/iter"
          },
          {
            "name": "bench_scipy_500",
            "value": 2478015,
            "range": "± 18263",
            "unit": "ns/iter"
          }
        ]
      }
    ]
  }
}